{extends file="layout.tpl"}

{*
 * These blocks replace corresponding blocks in the base theme layout.tpl file
 * These blocks can themselves be replaced/prepended/appended by blocks in the child theme.tpl file
 * Brace characters are assumed to be Smarty delimiters UNLESS surrounded by white space
 *}
 
{block "headfirst"}
{if $ss_googleAnalyticsId ne '' && $ss_googleAnalyticsType eq 'gtag'}
    <!-- Global site tag (gtag.js) - Google Analytics -->
    <script async src="https://www.googletagmanager.com/gtag/js?id={$ss_googleAnalyticsId}"></script>
    <script>
      window.dataLayer = window.dataLayer || [];
{literal}
      function gtag(){dataLayer.push(arguments);}
{/literal}
      gtag('js', new Date());
      gtag('config', '{$ss_googleAnalyticsId}');
    </script>
{/if}{/block}

{block "meta"}
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <title dir="ltr">{$ss_siteTitle} | {$ss_navName}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="keywords" content="{$ss_metaKeywords}">
    <meta name="description" content="{$ss_pageDescription}">
    <meta property="og:title" content="{$ss_ogTitle}">
    <meta property="og:type" content="website">
    <meta property="og:url" content="http://{$ss_hostName}{$ss_pageUrl}/">
    <meta property="og:description" content="{$ss_pageDescription}">
{if $ss_ogImageUrl ne ''}
    <meta property="og:image" content="http://{$ss_ogImageUrl}">
{/if}{/block}

{block "stylelinks"}
    <link rel="stylesheet" href="{$ss_themeUrl}/css/styles.css">
    <link rel="stylesheet" href="{$ss_themeUrl}/css/custom.css">
{/block}


{block "scriptlinks"}
    <script src="{$ss_themesUrl}/base/js/jquery-min.js"></script>
    <script src="{$ss_themesUrl}/base/js/modernizr.custom.js"></script>
    <script src="{$ss_themesUrl}/base/js/base.js"></script>
    <!--[if (lt IE 9) & (gt IE 6) & (!IEMobile)]>
      <script src="{$ss_themesUrl}/base/js/selectivizr-min.js"></script>
      <script src="{$ss_themesUrl}/base/js/respond.min.js"></script>
    <![endif]-->
{/block}


{block "styles"}
      /* base font size */
      body {
        font-size: {$bodyFontPercent}%;
      }
      body.background-image {
        background-image: url({$backgroundImageSrc});
      }
      /* Site max width */
      #wrapper {
        max-width: {$ss_siteMaxWidth}px;
      }
  {if $themePalette eq 'custom'}
      /* Custom colors */
      .custom {
        background-color: {$customBackgroundColor};
        color: {$customForegroundColor};
      }
      /* logo */
      .custom #wrapper .hgroup h1, 
      .custom #wrapper .hgroup h1 a:link,
      .custom #wrapper .hgroup h1 a:visited,
      .custom #wrapper .hgroup h1 a:focus,
      .custom #wrapper .hgroup h1 a:hover,
      .custom #wrapper .hgroup h1 a:active {
        color: {$customHeading1Color};
      }
      /* links styles */
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):link,
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):visited,
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):focus {
        color: {$customLinkColor};
      }
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):hover,
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):active {
        color: {$customHoverColor};
      }
      .custom #wrapper header nav ul li.active > a:link,
      .custom #wrapper header nav ul li.active > a:visited,
      .custom #wrapper header nav ul li.active > a:focus
       {
        color: {$customUrhereColor};
      }
      .custom #wrapper header nav ul li.active > a:hover,
      .custom #wrapper header nav ul li.active > a:active {
        color: {$customHoverColor};
      }
      /* content styles */
      .custom h1 {
        color: {$customHeading1Color};
      }
      .custom h2,
      .custom h3,
      .custom h4 {
        color: {$customHeading2Color};
      }
      /* borders */
      .custom * {
        border-color: {$customBorderColor};
      }
      /* forms */
      .custom .invalid,
  	  .custom .error {
    	  color: {$customWarningColor};
    	  border-color: {$customWarningColor};
  	  }
  	  .custom input:focus,
  	  .custom textarea:focus {
    	  border-color: {$customUrhereColor};
  	  }
  	  .custom input[type=submit] {
    	  color: {$customForegroundColor};
  	    background-color: {$customBackgroundColor};
  	  }
      /* warning messages */
      .custom .error,
      .custom .invalid {
        color: {$customWarningColor};
        border-color: {$customWarningColor};
      }
    {/if}{/block}

{block "headlast"}
{if $ss_googleAnalyticsId ne '' && $ss_googleAnalyticsType eq 'ga'}
    <!-- Legacy site tag (ga.js) - Google Analytics -->
    <script type="text/javascript">
      var _gaq = _gaq || [];
      _gaq.push(['_setAccount', '{$ss_googleAnalyticsId}']);
      _gaq.push(['_trackPageview']);
      (function() {
        var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
        ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
        var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
      })();
    </script>
{/if}{/block}


{block "header"}
        <div class="hgroup">
        {block "hgroup"}
          <h1>
{if $siteLogoSrc ne ''}
            <a href="{$ss_siteHeaderLink}"><img src="{$siteLogoSrc}" alt="{$ss_siteTitle}"></a>
{/if}
{if $ss_siteHeading ne ''}
            <a href="{$ss_siteHeaderLink}">{$ss_siteHeading}</a>
{/if}
          </h1>
{if $ss_siteSubHeading ne ''}
          <h2>{$ss_siteSubHeading}</h2>
{/if}
          <div id="nav-anchors" class="nav-anchors">
            <a href="#nav" id="menu-anchor"><span class="icon-menu" aria-hidden="true"></span></a>
          </div>
        {/block}
        </div>
        <nav  id="nav" class="header-nav-items hidden-nav">
        {block "nav"}
{$ss_navLinks}
        {/block}
        </nav> 
{/block}


{block "body" append}
    <script src="{$ss_themesUrl}/base/js/jquery.fitvids.js"></script>
    <script>
      $("section.content").fitVids();
    </script>
    <script src="{$ss_themeUrl}/js/custom.js"></script>
{/block}


{block "footer"}
        <div class="socmedia">
          <a href="{$facebookLink}" title="facebook"><span class="icon-facebook2"></span></a>
          <a href="{$flickrLink}" title="flickr"><span class="icon-flickr3"></span></a>
          <a href="{$googleplusLink}" title="Google+"><span class="icon-google-plus2"></span></a>
          <a href="{$instagramLink}" title="Instagram"><span class="icon-instagram"></span></a>
          <a href="{$linkedinLink}" title="LinkedIn"><span class="icon-linkedin"></span></a>
          <a href="{$pinterestLink}" title="Pinterest"><span class="icon-pinterest2"></span></a>
          <a href="{$tumblrLink}" title="Tumblr"><span class="icon-tumblr2"></span></a>
          <a href="{$twitterLink}" title="Twitter"><span class="icon-twitter2"></span></a>
          <a href="{$vimeoLink}" title="Vimeo"><span class="icon-vimeo2"></span></a>
        </div>
        <small>{$ss_siteFooter}</small>
{/block}
