{extends file='basetheme.tpl'}

{*
 * This file provides a link between the page templates and the base theme template
 * Any blocks added to this file will override/prepend/append corresponding blocks in the base theme template
 *}
 
{* Split css files into base and theme for easier development *}
{block "stylelinks" prepend}
  {if $bodyFont eq 'open-sans' or $headingsFont eq 'open-sans'}
    <link href='//fonts.googleapis.com/css?family=Open+Sans:400,700' rel='stylesheet' type='text/css'>
  {/if}
{/block}

{block "scriptlinks" append}
    <script src="{$ss_themeUrl}/js/theme.js"></script>
{/block}

{* Maribo uses rem font sizing so body font must be set on html
   Site max width is not needed
*}
{block "styles"}
      /* base font size */
      html {
        font-size: {$bodyFontPercent}%;
      }
      body.background-image {
        background-image: url({$backgroundImageSrc});
      }
      
  {if $showHomeNav eq 'false'}
      /* Show/hide home page in nav */
      nav > ul:first-child > li:first-child {
        display: none;
      }
  {/if}
  
  {if $showGallerySubNav eq 'false'}
      /* Show/hide gallery and gallery index sub-nav */
      .type-galleryindex .subnav,
      .type-juicebox .subnav,
      .type-simpleviewer .subnav,
      .type-listviewer .subnav {
        display: none;
      }
  {/if}
  
  {if $themePalette eq 'custom'}
    /* Custom colors */
      .custom {
        background-color: {$customBackgroundColor};
        color: {$customForegroundColor};
      }
      /* borders */
      .custom * {
        border-color: {$customBorderColor};
      }
      /* forms */
      .custom .invalid,
  	  .custom .error {
    	  color: {$customWarningColor};
    	  border-color: {$customWarningColor};
  	  }
  	  .custom input:focus,
  	  .custom textarea:focus {
    	  border-color: {$customUrhereColor};
  	  }
  	  .custom input[type=submit] {
    	  color: {$customForegroundColor};
  	    background-color: {$customBackgroundColor};
  	  }
      /* links styles */
      .custom #menu-anchor.active {
        color: {$customUrhereColor};
      }
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):link,
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):visited,
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):focus {
        color: {$customLinkColor};
        border-bottom-color: {$customLinkColor};
      }
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):hover,
      .custom a:not(.jb-splash-view-glry):not([class*="jb-go-back"]):active {
        color: {$customHoverColor};
        border-bottom-color: {$customHoverColor};
      }
      /* Header */
      .custom #wrapper .hgroup h1, 
      .custom #wrapper .hgroup h1 a:link,
      .custom #wrapper .hgroup h1 a:visited,
      .custom #wrapper .hgroup h1 a:focus,
      .custom #wrapper .hgroup h1 a:hover,
      .custom #wrapper .hgroup h1 a:active {
        color: {$customHeading1Color};
      }
      /* Nav */
      .custom header nav ul li.active > a:link,
      .custom header nav ul li.active > a:visited,
      .custom header nav ul li.active > a:focus {
        color: {$customUrhereColor};
      }
      .custom header nav ul li.active > a:hover,
      .custom header nav ul li.active > a:active {
        color: {$customHoverColor};
      }
      .custom .icon-menu {
        color: {$customForegroundColor};
       }
      .custom .active .icon-menu {
        color: {$customBackgroundColor};
      }
      .custom .nav a:link,
      .custom .nav a:visited {
        color: {$customBackgroundColor};
      }
      .custom .nav a:hover,
      .custom .nav a:active {
        color: {$customHoverColor};
      }
      .custom .nav li {
        background-color: {$customForegroundColor};
        border-color: #999;
      }
      .custom .nav li.active > a:link,
      .custom .nav li.active > a:visited {
        color: {$customUrhereColor};
      }
      /* content styles */
      .custom h1 {
        color: {$customHeading1Color};
      }
      .custom h2,
      .custom h3,
      .custom h4 {
        color: {$customHeading2Color};
      }
    
    @media only screen and (min-width: 768px) {
      .custom .nav li {
        background-color: transparent;
      }
      .custom .nav li > a:link,
      .custom .nav li > a:visited {
        color: {$customForegroundColor};
        background-color: transparent;
      }
      .custom .nav li > a:hover,
      .custom .nav li > a:active {
        color: {$customHoverColor};
      }
    }
  {/if}

{/block}

{* Nav comes before h1 in Maribo. Also hiding the nav to prevent nav flash on load *}
{block "header"}
        <nav  id="nav" class="header-nav-items hidden-nav">
{$ss_navLinks}
        </nav>
        <div class="hgroup">
        {block "hgroup"}
          <h1>
{if $siteLogoSrc ne ''}
            <a href="{$ss_siteHeaderLink}"><img src="{$siteLogoSrc}" alt="{$ss_siteTitle}"></a>
{/if}
{if $ss_siteHeading ne ''}
            <a href="{$ss_siteHeaderLink}">{$ss_siteHeading}</a>
{/if}
          </h1>
{if $ss_siteSubHeading ne ''}
          <h2>{$ss_siteSubHeading}</h2>
{/if}
          <div id="nav-anchors" class="nav-anchors">
            <a href="#nav" id="menu-anchor"><span class="icon-menu" aria-hidden="true"></span></a>
          </div>
        {/block}
        </div>

{/block}
