<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2012, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
/**
 * Authentication class
 *
 * @access public
 * @package Showkase
 */
Class Auth
{
    /**
     * @var object instance of site singleton
     */
    private $config;
    
    /**
     * Constructor
     *
     */
    public function __construct() {
        $this->config = SkConfig::getInstance();
    }  
  
   /**
    * Sets-up the session variables for valid users
    *
    * @access public
    * @return boolean logged-in
    */
    public function login() {
        if (!isset($_POST['loginsubmitted'])) {
            return !empty($_SESSION[SESSION_USER]);
        }
        if (!isset($_POST['user']) || !isset($_POST['password'])) {
            return false;
        }
        $_SESSION[SESSION_USER] = null;
        if (!$this->confirmPass($_POST['user'], $_POST['password'])) {
            Board::addMessage('Incorrect user name or password', 'error');
            return false;
        }
        $_SESSION[SESSION_DEFAULT_PASS] = ($_POST['password'] == 'admin');
        $_SESSION[SESSION_USER]         = $_POST['user'];
        $_SESSION[LOGIN_TIME]           = time();
        unset($_POST['password'], $_POST['user']);
        return true;  
    }
    
    /* Confirm user name and password
    * Used for login and password change
    * @param plain text password
    * @param user name
    * @return boolean
    */
    public function confirmPass($user, $plainPass) {
        $validPass = false;
        $passwordNeedsRehash = false;
        $authData = array();
        try {
            $authData = $this->readAuthData();
        }  catch (Exception $e) {
            Board::addMessage($e->getMessage(), 'error');
            return false;
        }
        sleep(SLEEP_TIME);
        if (!isset($authData[$user])) return false;
        if (
            version_compare(PHP_VERSION, '5.5.0', '>=')
            && strlen($authData[$user]) > 50
        ) {
            $validPass = password_verify($plainPass, $authData[$user]);
            $passwordNeedsRehash = password_needs_rehash($authData[$user], PASSWORD_DEFAULT);
        } else {
            $salt = substr($authData[$user], 0, SALT_LENGTH);
            $validPass = ($authData[$user] == $salt.sha1($salt.$plainPass));
            if (version_compare(PHP_VERSION, '5.5.0', '>=')) {
                $passwordNeedsRehash = true;
            }
        }
        if ($passwordNeedsRehash && !DEMO_MODE) {
            $this->changeLogin($user, $plainPass);
        }
        return $validPass;
    }
    
    /**
     * Attempt to read auth file or reset file
     *
     * @return array of auth data
     */
    private function readAuthData()
    {
        $noFileMessage = (DEMO_MODE)
            ? 'Demo is off-line. Please try again later.'
            : 'Error: cannot find authorisation data';
        $authPath = file_exists($this->config->getAuthResetPath())
            ? $this->config->getAuthResetPath()
            : $this->config->getAuthPath();
        if (!file_exists($authPath)) {
            throw new Exception($noFileMessage);
        }
        if (!is_readable($authPath)) {
            throw new Exception('Error: cannot read the authorisation file');
        }
        @$authData = file_get_contents($authPath);
        if ($authData === false) {
            throw new Exception('Error: cannot get authorisation file contents');
        }
        $authData = substr($authData, 16);
        @$authData = unserialize($authData);
        if (!is_array($authData) || (count($authData) != 1)) {
            throw new Exception('Error: authorisation file format is incorrect');
        }
        return $authData;
    }
    
   /*
    * Change user name and password
    * Also used during setup
    *
    * @access public
    * @return boolean true on success
    * @param string user name
    * @param string password
    */
    public function changeLogin($user, $password)
    {
        if (version_compare(PHP_VERSION, '5.5.0', '>=')) {
            $passwordHash = password_hash($password, PASSWORD_DEFAULT);
        } else {
            $salt = substr(md5(uniqid(mt_rand(), true)), 0, SALT_LENGTH);
            $passwordHash = $salt.sha1($salt.$password);
        }
        if ($passwordHash === false) {
            throw new Exception('User and password have not been changed: unable to generate password hash');
        }
        $authData = '<?php exit(); ?>'.serialize(array($user => $passwordHash));
        if (false === Filer::skPutContents($this->config->getAuthPath(), $authData, LOCK_EX)) {
            throw new Exception('User and password have not been changed: unable to store new user name and password');
        }
        $_SESSION[SESSION_DEFAULT_PASS] = ($password == 'admin');
        $_SESSION[SESSION_USER]         = $user;
        $_SESSION[LOGIN_TIME]           = time();
        return true;
    }
    
    /**
    * Destroy session and cookies
    * http://www.php.net/manual/en/function.session-destroy.php
    *
    * @return void
    */
    public function logout() {
        if (!isset($_SESSION)) return;
        $_SESSION = array();
        if (ini_get("session.use_cookies")) {
            $params = session_get_cookie_params();
            setcookie(
                session_name(),
                '',
                time() - 42000,
                $params["path"],
                $params["domain"],
                $params["secure"],
                $params["httponly"]
            );
        }
        session_destroy();
    }
}
