<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2013, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
$ds = DIRECTORY_SEPARATOR;
require_once "classes{$ds}gallerylink.php";

class GalleryIndex
{
  /**
   * @var array gallery index data
   */
  private $galleryIndexData = array();
  
  /**
   * Constructor
   *
   * @param object instance of PageSet
   * @return void
   */
  public function __construct(PageSet $pageSet)
  {
    $config = SkConfig::getInstance();
    $pagesData = $pageSet->getPagesData();
    $weights = array();
    foreach ($pagesData as $key=>$pageData) {
        $pagesDataIndex[$pageData['pageRef']] = $key;
    }
    unset($key, $pageData);
    foreach ($pagesData as $key=>$pageData) {
        // Skip gallery index pages to avoid danger of infinite loop
        if (
            $pageData['pageType'] == 'galleryindex'
            || !$pageData['isGallery']
        ) continue;
        $this->galleryIndexData[$key] = $pageData;
        if (!isset($pageData['parentPage'])) {
          $this->galleryIndexData[$key]['parentPage'] = 0;
        }
        $parentPage = $this->galleryIndexData[$key]['parentPage'];
        // use string true/false rather than boolean for consistency with other page data
        $this->galleryIndexData[$key]['hiddenParent'] = (
                $parentPage > 0
                && strtolower($pagesData[$pagesDataIndex[$parentPage]]['navShow']) === 'false'
            )
            ? 'true'
            : 'false';
        $this->galleryIndexData[$key]['galleryUrl']  = 
            $config->getContentUrl()
            .'/'
            .str_replace('\\', '/', basename($pageData['path']))
            .'/';
        $this->galleryIndexData[$key]['thumbUrl'] = 
            $config->getThumbCacheUrl()
            .'/'
            .INDEX_THUMB_PREFIX
            .$pageData['pageRef']
            .'.jpg';
        $this->galleryIndexData[$key]['imageCount']
            = isset($pageData['imageCount'])
            ? $pageData['imageCount']
            : 0;
        $this->galleryIndexData[$key]['imageCountString']
            = ($this->galleryIndexData[$key]['imageCount'] == 1)
            ? $this->galleryIndexData[$key]['imageCount'].' image'
            : $this->galleryIndexData[$key]['imageCount'].' images';
        $weights[$key] = isset($pageData['navWeight']) ? $pageData['navWeight'] : 0;
      }
      array_multisort($weights, $this->galleryIndexData);
  }
   
  /**
   * Get array of gallery link objects
   *
   * @return array
   * @param object instance of Page
   * @param boolean return page group links only
   */
   public function getGalleryLinks(Page $page, $group=false)
   {
        $theme = $page->getTheme();
        $size = $theme->getIndexThumbSize();
        $indexThumbFormat =
            $size['width'] == 0
            ? 100
            : 100*$size['height']/$size['width'];
        $galleryLinks = array();
        foreach ($this->galleryIndexData as $key=>&$data) {
           if ($group && ($data['parentPage'] != $page->getRef())) continue;
           if (
               isset($data['indexShow'])
               && strtolower($data['indexShow']) === 'false'
               && $data['hiddenParent'] === 'false') {
                   continue;
               }
           if (isset($data['supported']) && strtolower($data['supported']) == 'false') continue;
           $data['thumbWidth']  = $size['width'];
           $data['thumbHeight'] = $size['height'];
           $data['thumbFormat'] = $indexThumbFormat;
           $galleryLinks[$key]  = new GalleryLink($data);
        }
        unset($data);
        return $galleryLinks;
   }
}
