<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2013, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
require_once 'classes'.DIRECTORY_SEPARATOR.'helpers.php';
require_once 'classes'.DIRECTORY_SEPARATOR.'customizescreenhelper.php';
 
/**
 * Customize screen
 *
 * @package Showkase
 */
class PageCustomizeScreen extends Screen
{
    /**
     * @var string overrides some of head content in Screen
     */
    protected $customHeadHtml;
    
    /**
     * @var object page
     */
    private $page;
    
    /**
     * @var string page type
     */
    private $pageType;
   
    /**
     * @var string tabs html
     */
    protected $subNavHtml;
    
    /**
     * @var object helper
     */
    private $helper;
    
    /**
     * constructor
     * @param string contains text for html <title></title> tags
     * @param string html id for body tag
     */
    public function __construct(Page $page, $classes="customize")
    {
        $this->page = $page;
        $this->pageType = $page->getPageType();
        parent::__construct('Showkase &ndash; customize', 'webpagecustomize', $classes.' '.$this->pageType);
        $this->helper = new CustomizeScreenHelper($page, $this->pageSet);
        $this->customHeadHtml = $this->helper->getCustomHeadHtml();
        $bbClass = ucfirst($page->getPluginType().'Buttonbar');
        $bb = new $bbClass();
        $this->subNavHtml = $bb->getHtml();
    }
  
    /**
     * get html for customize screen
     *
     * @return string html
     * @param array context
     */
    public function getContentHtml($context)
    {
      $headerHtml = '
        <h2>'.htmlspecialchars($this->page->getNavName(), ENT_QUOTES, 'UTF-8').'</h2>
        <h3>'.$context['pageTypes'][$this->page->getPageType()]['name'].'</h3>';
      if (!$this->page->isSupportedPageType()) return $headerHtml;
      $proHeader = $this->pageType == 'juicebox' || $this->pageType == 'simpleviewer'
              ? '<h3>Pro Viewer Options</h3>'
              : '';
      $liteFields = $this->helper->getLiteFields();
      $proFields = $this->helper->getProFields();
      $tab = 0;
      $liteHtml = $this->getFieldsHtml($liteFields, $tab);
      $proHtml = $this->getFieldsHtml($proFields, $tab);
      $formButtonHtml = $this->helper->getFormButtonHtml($context);
      $html = $this->getColorjackHtml();  
      $html .= <<<EOD
      <form class="changecheck form-horizontal" action = "index.php?cmd=pagecustomize" id="customizeform" method="post">
        <div class="subhead">
          <div class="hgroup">
            {$headerHtml}
          </div>
          {$formButtonHtml}
        </div>
        {$liteHtml}
        {$proHeader}
        {$proHtml}
      </form>
EOD;
      return $html;
    }
}
