<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2016, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>'); 
require_once 'classes'.DIRECTORY_SEPARATOR.'screen.php';
require_once 'classes'.DIRECTORY_SEPARATOR.'helpers.php';
 
/**
 * Pages screen
 *
 * @package Showkase
 */
class PagesScreen extends Screen
{
  /**
    * @var string overrides some of html in parent
    */
    protected $customHeadHtml = '
    <link rel="stylesheet" href="jstree/themes/default/style.min.css" >
    <script src="jstree/jstree.min.js"></script>
    <script src="scripts/jpages.js"></script>
    ';

  /**
   * Returns list of pages as html table
   * @access public
   * @return string html table
   * @param array context
  */
  function getContentHtml($context)
  {
    $weights     = array();
    $pageIndices = array();
    $validRefs   = array();
    $siteTitle   = $context['siteTitle'];
    $pagesData   = $this->pageSet->getPagesData();
    foreach ($pagesData as $key=>$pageData) {
        $weights[] = isset($pageData['navWeight']) ? $pageData['navWeight'] : 0;
        $pageIndices[$pageData['pageRef']] = $key;
        $validRefs[] = $pageData['pageRef'];
    }
    unset($key, $pageData);
    array_push($validRefs, '0', '-1');
    array_multisort($weights, $pagesData);
    $pagesPrefs = $this->pageSet->getPagesPrefs();
    $newPageHtml    = '';
    // new page
    foreach ($context['pageTypes'] as $type=>$pageTypeData) {
      if (isset($pageTypeData['exposed']) && strtolower($pageTypeData['exposed']) == 'false') continue;
      $newPageHtml .= '
      <tr>
        <td>'.$pageTypeData['name'].'</td>
        <td class="commit"><button value="'.$type.'" type="submit" name="newpage" class="btn btn-success">Create</button></td>
      </tr>
';
    }
    unset($type, $pageTypeData);
    if ($newPageHtml == '') {
      $newPageHtml = '
      <tr>
        <td>No plugins available</td>
      </tr>
';
    }
    $html = <<<EOD
    <form class="form-horizontal" action = "index.php?cmd=showpages" id="pagesform" method="post">
      <div id="newpage" class="modal hide fade">
        <div class="modal-header">
          <a class="btn btn-danger close" data-dismiss="modal" href="#">Cancel</a>
          <h3>Create new web page</h3>
        </div>
        <div class="modal-body">
          <table class="showkase-actions">
            {$newPageHtml}
          </table>
        </div>
      </div>
    
    	  <div class="subhead">
    	    <div class="hgroup">
            <h2>{$siteTitle}</h2>
          </div>
          <ul class="buttons unstyled">
            <li><button type="button" onclick="skGlobals.lastClicked='cancel';window.location='index.php';" class="btn btn-danger cancel">Cancel</button></li>
            <li><button type="submit" title="Save changes" name="update" class="btn btn-success formbutton" >Save</button></li>
            <li><button type="button" class="btn btn-success" data-toggle="modal" data-target="#newpage" data-backdrop="true" title="Create new page for your web site"><span>New&nbsp;Page</span></button></li>
          </ul>
        </div>
        <br class="clearboth">
        <input id="treejson" type="hidden" name="treejson">
        <input type="hidden" name="token" value="{$context['token']}" >
    </form>
EOD;
    if (count($pagesData) == 0) {
        $html .= '<div class="prompt">Click <i>New Page</i> to start building your web site.</div>';
        return $html;
    }
    $html .= '
    <!-- jstree -->
      <div id="container"></div>
    <script>
    $(function() {
      var notGalleryIndex = ["juicebox", "listviewer", "simpleviewer", "about", "basic", "contact", "link"];
      $("#container").jstree({
        "contextmenu" : {
            "items" : customMenu
        },
        "plugins" : ["dnd", "contextmenu", "types", "wholerow"],
        "types" : {
          "#" : {
            "max_depth" : 3,
            "max_children" : 3
            /* alternatively
            "valid_children" : ["pages", "hidden", "trash"]
            */
          },
          "show" : {icon: "icon-stack"},
          "hide" : {icon: "icon-eye-blocked"},
          "trash" : {icon: "icon-bin"},
          "juicebox" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "listviewer" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "simpleviewer" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "about" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "basic" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "contact" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "galleryindex" : {
             icon : false,
             valid_children : notGalleryIndex
          },
          "link" : {
             icon : false,
             valid_children : notGalleryIndex
          }
        },
        "dnd" : {
          "copy" : false,
          "is_draggable" : function(node) {
            return (node[0].parent != "#");
          }
        },
        "core" : {
          "check_callback" : true, // enable all modifications
          "themes" : {
          "name" : false,
          "variant" : "large", // variant just changes some of the tree css classes
          "stripes" : false,
          "dots" : false,
          },
          "data" : [
          {
            "id" : "ref0",
            "type" : "show",
            "parent" : "#",
            "text" : "<span class=\"level1\" title=\"Drag pages to rearrange, right-click for menu.\">Public pages</span>",
            "state" :{"opened" :true}
          },
            
';
      foreach ($pagesData as $key=>$pageData) {
          $pageLabel = $context['pageTypes'][$pageData['pageType']]['name'];
          $pageType  = $pageData['pageType'];
          $pageRef   = $pageData['pageRef'];
          $pagePath  = $pageData['path'];
          $navName   = htmlspecialchars($pageData["navName"], ENT_NOQUOTES, 'UTF-8', false);
          $navName   = str_replace('\\', '\\\\', $navName);
          $navName   = str_replace("'", "\\'", $navName);
          $pageIndex = $pageIndices[$pageData['pageRef']];
          // some older versions stored $pageData['supported'] as bool for non-galleries only
          switch (true) {
              case !isset($pageData['supported']) :
                  $supported = '';
                  break;
              case is_bool($pageData['supported']) && $pageData['supported'] === false :
              case is_string($pageData['supported']) && strtolower($pageData['supported']) === 'false' :
                  $supported = 'unsupported';
                  break;
              default :
                  $supported = '';
          }
          $pageUrl   = str_replace('\\', '/', $pageData['path']);
          $parentPage = $pageData['parentPage'];
          // Integrity check - missing parents will crash jsTree
          if (!in_array($parentPage, $validRefs)) {
              Board::addMessage("Cannot find parent for ".$navName.", moving to public pages");
              $parentPage = '0';
          }
          $html .= <<<EOD
          {
            'id'     : 'ref{$pageRef}',
            'parent' : 'ref{$parentPage}',
            'text'   : 
              '<span class="sk-navname sk-action sk-menu {$supported}">{$navName}</span>' + 
              '<span class="sk-pagetype">{$pageLabel}</span>' +
              '<i class="icon-pencil action-icon"></i><a class="sk-action sk-edit">Edit</a>' +
              '<i class="icon-price-tag action-icon"></i><a class="sk-action sk-rename">Rename</a>' +
              '<i class="icon-eye action-icon"></i><a class="sk-action sk-view {$supported}">View</a>',
            'type'   : '{$pageType}',
            'state'  : {'opened' : true},
            'data'   : {
              'pageindex' : '{$pageIndex}',
              'pageurl'   : '$pageUrl',
              'navname'   : '{$navName}'
            }
          },
EOD;
      }
      $html .= '
          {
            "id" : "ref'.PAGE_HIDDEN_PARENT.'",
            "parent" : "#",
            "text" : "<span class=\"level1\" title=\"Drag pages here to hide in site navigation.\">Hidden pages</span>",
            "type" : "hide",
            "state" : {"opened" : true}
          },
          {
            "id" : "ref'.PAGE_TRASH_PARENT.'",
            "text" : "<span class=\"level1\" title=\"These pages will be deleted on next save.\">Trash</span>",
            "parent" : "#",
            "type" : "trash",
            "state" : {"opened" : true}
          }
          ]
        }
      });
    });
    </script>
    <!-- end jstree -->
'; 
    return $html;    
  }
}
