<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2019, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
require_once "smarty".DIRECTORY_SEPARATOR."Smarty.class.php";

class Publisher
{
     
    /**
     * Republish the whole web site
     * Nav object is created once only
     * Need to save (at least) the gallery in case of changes in viewer settings
     * Each viewer is re-cached once only
     *
     * @param object PageSet
     * @param object ThemeSet
     * @param object PageFactory
     * @param object GalleryIndex
     * @param object Nav
     * @return void
     */
    public static function republish(
        PageSet $pageSet,
        ThemeSet $themeSet,
        PageFactory $pageFactory,
        GalleryIndex $galleryIndex,
        Nav $nav
    )
    {
        $config = skConfig::getInstance();
        $cachedViewers = array();
        $viewersPath = $config->getAbsoluteViewersPath();
        $smarty = new Smarty();
        foreach ($pageSet->getPagesData() as $key=>$value) {
            $imageCount = 0;
            try {
                $page = $pageFactory->make($value['pageType'], $value['pageRef'], $value['path']);
                // update viewer cache once for each page type
                if (!isset($cachedViewers[$value['pageType']])) {
                    $page->cacheViewer($viewersPath);
                    $cachedViewers[$value['pageType']] = true;
                }
                if (isset ($page->gallery)) {
                    $page->gallery->updateIndexThumb();
                    $page->gallery->saveGallery(true);
                    $page->gallery->updateMultiImages();
                    $imageCount = $page->getImageCount();
                }
                $page->saveLayer();
                $pageSet->setPagesDataImageCount($key, $imageCount);
                $page->savePageHtml($pageSet, $nav, $galleryIndex, $smarty);
                
            } catch (Exception $e) {
                Board::addExceptionMessage($e);
            }
            unset($page->gallery);
        }
        $pageSet->savePagesData();
    }
}