<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2012, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
$ds = DIRECTORY_SEPARATOR;
require_once "classes{$ds}formfield.php";
require_once "classes{$ds}helpers.php";

class RgbaColorField extends FormField
{
    /**
     * @var array(hex, alpha)
     */
    private $iniHexAlpha = array();
    
    /**
     * constructor
     * Values other than 'true' and 'false' can be set in ini file
     */
    public function __construct(array $iniVars)
    {
        parent::__construct($iniVars);
        $this->iniHexAlpha = Helpers::rgbaToHex($this->iniValue);
    }
    
    /**
     * Set value
     * Overrides parent method
     * Originally set from ini file string, updated from an array
     *
     * @return void
     * @param value array or string
     */
    public function setValue($value)
    {
        if (is_array($value)) {
            $hex = trim(strtolower($value[0]));
            $hex = ltrim($hex, '#');
            $hex = str_replace('0x', '', $hex);
            $hex =  str_pad(strtoupper(dechex(hexdec(substr(trim($hex), 0, 6)))), 6, '0', STR_PAD_LEFT);
            $rgb = Helpers::hexToRgb($hex);
            $a   = min(max(0, $value[1]), 1);
            $this->value = "rgba({$rgb['red']},{$rgb['green']},{$rgb['blue']},{$a})";
            } else {
            $this->value = $value;
        }
    }

    /**
     * Formats html string
     * Used outside the print/echo context
     *
     * @return string
     */
    public function getHtml(&$tab)
    {
      $tab++;
      $alphaTab = $tab + 1;
      $iniHtml = array('', '');
      $hexAlpha = Helpers::rgbaToHex($this->value);
      $label = $this->getLabel();
      $alphaId = $this->id.'-alpha';
      $alphaName = $this->name.'Alpha';
      /*
      if ($this->value != $this->iniValue) {
          $iniHexAlpha = Helpers::rgbaToHex($this->iniValue);
          $iniHtml[0]  = '<span class="inivalue">'.$iniHexAlpha[0].'</span>';
          $iniHtml[1]  = '<span class="inivalue">'.$iniHexAlpha[1].'</span>';
      }
      */
      $hexDivClass =
          $hexAlpha[0] === $this->iniHexAlpha[0]
          ? 'input default'
          : 'input';
      $alphaDivClass =
          $hexAlpha[1] === $this->iniHexAlpha[1]
          ? 'input default'
          : 'input';
      $html = <<<EOD
<div class="control-group">
  {$label}
  <div class="{$hexDivClass}">
    <input type="text" class="colorpicker" name="{$this->name}" id="{$this->id}" tabindex="{$tab}" value="{$hexAlpha[0]}" data-sk-default="{$this->iniHexAlpha[0]}">
    <button type="button" class="reset" title="reset" data-sk-for="{$this->id}">
      <span class="icon-undo"></span>
    </button>
  </div>
</div>
<div class="control-group">
  <label for="{$alphaId}" class="tipper" title="Range 0-1 (0 = transparent)">Opacity&nbsp;<img src="img/comment.png" alt="tooltip icon"></label>
  <div class="{$alphaDivClass}">
    <input type="text" class="text" name="{$alphaName}" id="{$alphaId}" tabindex="{$alphaTab}" value="{$hexAlpha[1]}" data-sk-default="{$this->iniHexAlpha[1]}">
    <button type="button" class="reset" data-sk-for="{$alphaId}">
      <span class="icon-undo"></span>
    </button>
  </div>
</div>
EOD;
      $tab++;
      return $html;
  }
}