<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2012, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
require_once 'classes'.DIRECTORY_SEPARATOR.'layer.php';
 
/**
 * About page
 *
 * @package Showkase
 */
class Site extends Layer
{
    /**
     * @var string page type
     */
    protected $pageType = 'site';
    
    /**
     * @var string page ref
     */
    protected $pageRef = 'site';
    
    /**
     * @var boolean
     */
    protected $supportedPageType = true;
    
    /**
     * @var object
     */
    protected $config;
    
    
    /**
     * Constructor
     */
    public function __construct(ThemeSet $themeSet)
    {
        $this->themeSet = $themeSet;
        $this->config = SkConfig::getInstance();
        $this->pagePathRelSvm =
            $this->config->getRelativeContentPath(getcwd()).
            '_data'.DIRECTORY_SEPARATOR.
            'sitedata'.DIRECTORY_SEPARATOR;
        $this->settingsPath = $this->pagePathRelSvm.'site.xml';
        $settingsDirectory = rtrim($this->pagePathRelSvm, '\\/');
        if (!file_exists($settingsDirectory)) {
            if (!Filer::skMkdir($settingsDirectory, NEW_DIR_MODE, true)) {
                throw new Exception('Cannot create site data folder, changes will not be saved.');
            }
        }
        $this->incomingFields = array();
        $this->layerFields = $this->readFieldInis($themeSet->getSiteIniPaths());
        foreach ($this->layerFields as $name => $field) {
            $this->layerDefaults[$name] = $field->getValue();
        }
        $layerSettings = PageReader::readPageVars($this->settingsPath);
        $deprecated = array('ss_metaDescription' => 'ss_pageDescription');
        $this->loadFields($this->layerFields, $layerSettings, $deprecated);
        $this->accumulatedFields = $this->layerFields;
    }
    
    /**
     * Is this page type a gallery
     *
     * @return boolean
     */
     public function isGallery()
     {
       return false;
     }
    
    /**
     * Check that site setup paths have not changed e.g. user moves site
     *
     * @return boolean paths ok
     */
    public function checkSetup()
    {
        $relContentPath = $this->config->getDocRootRelativeContentPath();
        $absContentPath = $this->config->getAbsoluteContentPath();
        $absInstallDir  = rtrim(dirname(getcwd()), '\\/').DIRECTORY_SEPARATOR;
        return
            $absContentPath    == $absInstallDir
            || $absContentPath == $absInstallDir.basename($relContentPath).DIRECTORY_SEPARATOR;
    }
}    