<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2019, SimpleViewer Inc.
 */
 defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
 $sep = DIRECTORY_SEPARATOR;
 require_once "commands{$sep}command.php" ;
 require_once "classes{$sep}pagefactory.php";
 require_once "classes{$sep}pageset.php";
 require_once "classes{$sep}screenfactory.php";
 require_once "classes{$sep}nav.php";
 require_once "classes{$sep}galleryindex.php";
 require_once "classes{$sep}publisher.php";
 require_once "classes{$sep}themeset.php";
 require_once "classes{$sep}site.php";
 require_once "smarty{$sep}Smarty.class.php";
 
/**
 * Command - Command Show and update images
 *
 * @package Showkase
 */
 class Images extends Command {
    function doExecute( Request $request ) {
        $themeSet = new ThemeSet();
        $context = array(
            'token' => $request->newToken(),
            'pageTypes' => $themeSet->getPageTypes()
        );
        $pageSet = new PageSet;
        $pageIndex = $pageSet->getCurrentPageIndex($request);
        $_SESSION['pageIndex'] = $pageIndex;
        $pageRef = $pageSet->getPageRef($pageIndex);
        $pageType = $pageSet->getPageType($pageIndex);
        $pagePath = $pageSet->getPagePath($pageIndex);
        $pageFactory = new PageFactory($themeSet);
        $page = $pageFactory->make($pageType, $pageRef, $pagePath);
        $post = $request->getPost();
        if (isset($post['imagessubmitted'])) {
            try {
                if (!$request->validatePost()) {
                    throw new Exception('No action. Re-submission or remote submission is not allowed.');
                }
                $page->gallery->setAllImageAttributes($post);
                if ($request->propertyIsSet('index')) {
                    $page->gallery->setIndexThumb($request->getProperty('index'));
                }
                if (!empty($post['del'])) {
                    $page->gallery->flagDeletedImages($post['del']);
                    if ($pageType != 'library') {
                        $pageSet->setPagesPref('publishing', 'unpublished');
                    }
                }
                $page->gallery->deleteImages();
                $page->gallery->saveGallery();
                // next line needed for Listviewer
                $page->savePageHtml($pageSet, new Nav($pageFactory, $pageSet), new GalleryIndex($pageSet), new Smarty());
                $pageSet->savePagesPrefs();
                Board::addMessage('Image data saved');
            } catch (Exception $e) {
                Board::addExceptionMessage($e);
            }
        }
        $imageObjects = $page->gallery->getImageObjects();
        $context['imageCount'] = $page->getImageCount();
        $pageSet->setPagesDataImageCount($pageIndex, $context['imageCount']);
        $pageSet->savePagesData();
        $indexThumb = $page->gallery->getIndexThumb();
        if (empty($indexThumb)) {
            try {
                $page->gallery->updateIndexThumb();
                $page->gallery->saveGallery();
            } catch (Exception $e) {
                Board::addExceptionMessage($e);
            }
        }
        $screenFactory = new ScreenFactory();
        $screen = $screenFactory->makeImagesScreen($pageType, $page);
        print $screen->getHtml($context);
    }
}
