<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2016, SimpleViewer Inc.
 */
 defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
 $sep = DIRECTORY_SEPARATOR;
 require_once "commands{$sep}command.php" ;
 require_once "classes{$sep}pagecustomizescreen.php";
 require_once "classes{$sep}pagefactory.php";
 require_once "classes{$sep}pageset.php";
 require_once "classes{$sep}helpers.php";
 require_once "classes{$sep}publisher.php";
 require_once "classes{$sep}themeset.php";
 require_once "classes{$sep}nav.php";
 require_once "classes{$sep}galleryindex.php";
 require_once "classes{$sep}urlify.php";
 require_once "classes{$sep}skconfig.php";
 require_once "smarty{$sep}Smarty.class.php";
 
/**
 * Command - show customize
 * Be careful of interactions between changing the folder and other settings
 * @package Showkase
 */
 class PageCustomize extends Command {
    function doExecute( Request $request ) {
        $config = SkConfig::getInstance();
        $pageSet = new PageSet();
        $themeSet = new ThemeSet();
        $pageFactory = new PageFactory($themeSet);
        $context = array(
            'token' => $request->newToken(),
            'pageTypes' => $themeSet->getPageTypes()
        );
        $pageIndex = $pageSet->getCurrentPageIndex($request);
        $_SESSION['pageIndex'] = $pageIndex;
        $pageRef = $pageSet->getPageRef($pageIndex); 
        $pageType = $pageSet->getPageType($pageIndex);
        $pagePath = $pageSet->getPagePath($pageIndex);
        $page = $pageFactory->make($pageType, $pageRef, $pagePath);
        if (!$page->isSupportedPageType()) {
            Board::addMessage('Current theme does not support <i>'.$pageType.'</i> page type.', 'warning');
        }
        $oldNavName = $page->getNavName();
        $post = $request->getPost();
        if ($request->propertyIsSet('customizesubmitted')) {
            if (!$request->validatePost()) {
                Board::addMessage('No action. Re-submission or remote submission is not allowed.', 'warning');
                $screen = new PageCustomizeScreen($page, 'pages customize');
                print $screen->getHtml($context);
            }
            try {
                $changes = $page->customize($post);
                if (isset ($page->gallery)) {
                    $page->gallery->saveGallery();
                }
                $page->saveLayer();
                $pageSet->setPagesDataIsGallery($pageIndex, isset ($page->gallery));
                $pageSet->setPagesDataParentPage($pageIndex, $page->getParentPage());
                $pageSet->setPagesDataNavWeight($pageIndex, $page->getNavWeight());
                $pageSet->setPagesDataNavName($pageIndex, $page->getNavName());
                $pageSet->setPagesDataNavShow($pageIndex, $page->getNavShow());
                $pageSet->setPagesDataIndexShow($pageIndex, $page->getIndexShow());
                $pageSet->setPagesDataSupported($pageIndex, $page->isSupportedPageType());
                $pageSet->savePagesData();
                $page->savePageHtml($pageSet, new Nav($pageFactory, $pageSet), new GalleryIndex($pageSet), new Smarty());
                Board::addMessage('Page settings saved');
                $triggers = array('ss_navName', 'ss_navWeight', 'ss_navShow', 'ss_indexShow', 'ss_parentPage', 'ss_customNavUrl', 'ss_customNavTarget');
                if(count(array_intersect($triggers, $changes)) > 0) {
                    $pageSet->setPagesPref('publishing', 'unpublished');
                    $pageSet->savePagesPrefs();
                }
            } catch (Exception $e) {
                Board::addExceptionMessage($e);
            }
        }
        $screen = new PageCustomizeScreen($page, 'pages customize');
        print $screen->getHtml($context);
    }
}
