<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2014, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
 // HTTP headers for no cache etc
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
header("Cache-Control: no-store, no-cache, must-revalidate");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");
$sep = DIRECTORY_SEPARATOR;
require_once "classes{$sep}pagefactory.php";
require_once "classes{$sep}themeset.php";
require_once "classes{$sep}pageset.php";
// change errors to exceptions
function exception_error_handler($errno, $errstr, $errfile, $errline ) {
    throw new ErrorException($errstr, $errno, 0, $errfile, $errline);
}
ini_set('html_errors', 0);
set_error_handler("exception_error_handler");

/**
 * Command - Repair
 *
 * @package Showkase
 */
 class Pluploader extends Command {
    function doExecute( Request $request ) {
        if (DEMO_MODE) {
            die('{"jsonrpc" : "2.0", "error" : {"code": 100, "message": "Demo version file not saved"}, "id" : "id"}');
        }
        try {
            $targetDir = $request->getProperty('skAbsImagePath');
            if (!file_exists($targetDir)) {
                if (!Filer::skMkdir($targetDir, NEW_DIR_MODE)) {
                    throw new Exception('Cannot create upload directory '.basename($targetDir));
                }
            }
            $lastChunk = $this->pluploadCode($targetDir);
            if (!$lastChunk) return;
            $pageRef     = $request->getProperty('skPageRef');
            $pageType    = $request->getProperty('skPageType');
            $pagePath    = $request->getProperty('skPagePath');
            $pageFactory = new PageFactory(new ThemeSet());
            $page        = $pageFactory->make($pageType, $pageRef, $pagePath);
            $page->gallery->addNewImages();
            if ($pageType == 'library') {
                $page->gallery->rebuild();
            } else {
                $pageSet     = new PageSet();
                $pageIndex   = $pageSet->getPageIndex($pageRef);
                $pageSet->setPagesPref('publishing', 'unpublished');
                $pageSet->savePagesPrefs();
                $imageCount = $page->getImageCount();
                $pageSet->setPagesDataImageCount($pageIndex, $imageCount);
                $pageSet->savePagesData();
            }
            $page->gallery->saveGallery(); 
        } catch (Exception $e) {
            die('{"jsonrpc" : "2.0", "error" : {"code": 100, "message": "'.$e->getMessage().' in '.basename($e->getFile()).', line '.$e->getLine().'"}, "id" : "id"}'); 
        }
        // Return JSON-RPC response moved from pluploadCode
        die('{"jsonrpc" : "2.0", "result" : null, "id" : "id"}');
    }
    
    /**
     * Plupload code from web site May 2013
     * Changed $targetDir
     * Added file cleanup from July 2012 script
     * Moved JSON success response up to calling script
     * Added return
     *
     * @param string absolute path to target directory with trailing separator
     * @return boolean finished chunked upload
     */
    private function pluploadCode($targetDir)
    {
        // 5 minutes execution time
        // edited out by jh causes problems on somve servers
        // @set_time_limit(5 * 60);
        
        // Uncomment this one to fake upload time
        // usleep(5000);
        
        // Settings
        //$targetDir = ini_get("upload_tmp_dir") . DIRECTORY_SEPARATOR . "plupload";
        //$targetDir = 'uploads';
        $cleanupTargetDir = true; // Remove old files
        $maxFileAge = 5 * 3600; // Temp file age in seconds
        
        
        // Create target dir
        if (!file_exists($targetDir)) {
        	@mkdir($targetDir);
        }
        
        // Get a file name
        if (isset($_REQUEST["name"])) {
        	$fileName = $_REQUEST["name"];
        } elseif (!empty($_FILES)) {
        	$fileName = $_FILES["file"]["name"];
        } else {
        	$fileName = uniqid("file_");
        }
        // Added by JH from July 2012 script
        $fileName = preg_replace('/[^\w\._]+/', '_', $fileName);
        
        $filePath = $targetDir . DIRECTORY_SEPARATOR . $fileName;
        
        // Chunking might be enabled
        $chunk = isset($_REQUEST["chunk"]) ? intval($_REQUEST["chunk"]) : 0;
        $chunks = isset($_REQUEST["chunks"]) ? intval($_REQUEST["chunks"]) : 0;
        
        
        // Remove old temp files	
        if ($cleanupTargetDir) {
        	if (!is_dir($targetDir) || !$dir = opendir($targetDir)) {
        		die('{"jsonrpc" : "2.0", "error" : {"code": 100, "message": "Failed to open temp directory."}, "id" : "id"}');
        	}
        
        	while (($file = readdir($dir)) !== false) {
        		$tmpfilePath = $targetDir . DIRECTORY_SEPARATOR . $file;
        
        		// If temp file is current file proceed to the next
        		if ($tmpfilePath == "{$filePath}.part") {
        			continue;
        		}
        		// Remove temp file if it is older than the max age and is not the current file
        		if (preg_match('/\.part$/', $file) && (filemtime($tmpfilePath) < time() - $maxFileAge)) {
        			@unlink($tmpfilePath);
        		}
        	}
        	closedir($dir);
        }	
        
        
        // Open temp file
        if (!$out = @fopen("{$filePath}.part", $chunks ? "ab" : "wb")) {
        	die('{"jsonrpc" : "2.0", "error" : {"code": 102, "message": "Failed to open output stream."}, "id" : "id"}');
        }
        
        if (!empty($_FILES)) {
        	if ($_FILES["file"]["error"] || !is_uploaded_file($_FILES["file"]["tmp_name"])) {
        		die('{"jsonrpc" : "2.0", "error" : {"code": 103, "message": "Failed to move uploaded file."}, "id" : "id"}');
        	}
        
        	// Read binary input stream and append it to temp file
        	if (!$in = @fopen($_FILES["file"]["tmp_name"], "rb")) {
        		die('{"jsonrpc" : "2.0", "error" : {"code": 101, "message": "Failed to open input stream."}, "id" : "id"}');
        	}
        } else {	
        	if (!$in = @fopen("php://input", "rb")) {
        		die('{"jsonrpc" : "2.0", "error" : {"code": 101, "message": "Failed to open input stream."}, "id" : "id"}');
        	}
        }
        
        while ($buff = fread($in, 4096)) {
        	fwrite($out, $buff);
        }
        
        @fclose($out);
        @fclose($in);
        
        // Check if file has been uploaded
        if (!$chunks || $chunk == $chunks - 1) {
        	// Strip the temp .part suffix off 
        	rename("{$filePath}.part", $filePath);
        }
        // added by JH
        return !$chunks || $chunk == $chunks-1;
    }
}
