<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2016, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
$sep = DIRECTORY_SEPARATOR;
require_once "commands{$sep}command.php" ;
require_once "classes{$sep}pagesscreen.php";
require_once "classes{$sep}themeset.php";
require_once "classes{$sep}site.php";
require_once "classes{$sep}skjson.php";
require_once "classes{$sep}helpers.php";
require_once "classes{$sep}urlify.php";
require_once "classes{$sep}skconfig.php";
require_once "classes{$sep}pagefactory.php";
require_once "classes{$sep}nav.php";
require_once "classes{$sep}galleryindex.php";
require_once "smarty{$sep}Smarty.class.php";

/**
 * Command - Show Pages
 *
 * @package Showkase
 */
class ShowPages extends Command
{
    function doExecute( Request $request )
    {
        $context = array('token' => $request->newToken());
        Board::addMessage($request->getFeedback());
        $config = SkConfig::getInstance(); 
        $pageSet = new PageSet();
        $themeSet = new ThemeSet();
        $pageFactory = new PageFactory($themeSet);
        $site = new Site($themeSet);
        $json = new SkJson();
        if (!$site->checkSetup()) {
            Board::addMessage('Site paths have changed. It may be necessary to run Setup.', 'warning');
        }
        try {
            if ($request->propertyIsSet('treejson')) {
                // save or new page clicked
                if (!$request->validatePost()) {
                    throw new Exception('No action. Re-submission or remote submission is not allowed.');
                }
                // test save pages data before changing any directories
                // is_writeable can fail on Win servers
                $pageSet->savePagesData();
                // Create new page first - helps to avoid duplicates
                if ($request->propertyIsSet('newpage')) {
                    $pageType = $request->getProperty('newpage');
                    $pageRef = $pageSet->nextPageRef();
                    $page = $pageFactory->make($pageType, $pageRef, '');
                    if (isset ($page->gallery)) {
                        $page->gallery->saveGallery();
                    }
                    $page->saveLayer();
                    $pageIndex = $pageSet->addPagesDataRecord($page);
                    $_SESSION['pageIndex'] = $pageIndex;
                    $pageSet->savePagesData();
                    //create index.html
                    $page->savePageHtml(
                        $pageSet,
                        new Nav($pageFactory, $pageSet),
                        new GalleryIndex($pageSet),
                        new Smarty()
                    );
                    Board::addMessage('New page created');
                }
                $json->init($request->getProperty('treejson'));
                $pageSet->updatePagesData($json, $themeSet, $pageFactory);
                $pageSet->savePagesData();
                $pageSet->setPagesPref('publishing', 'unpublished');
                $pageSet->savePagesPrefs();
            }
        } catch (Exception $e) {
            Board::addExceptionMessage($e, 'error');
        }
        $context['pageTypes'] = $themeSet->getPageTypes();
        $context['siteTitle'] = $site->getLayerVar('ss_siteTitle');
        $screen = new PagesScreen('Showkase &ndash; pages', 'pages', 'pages');
        print $screen->getHtml($context);
    }
}
