<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2019, SimpleViewer Inc.
 */
 defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
 $sep = DIRECTORY_SEPARATOR;
 require_once "commands{$sep}command.php" ;
 require_once "classes{$sep}pagefactory.php";
 require_once "classes{$sep}pageset.php";
 require_once "classes{$sep}sortscreen.php";
 require_once "classes{$sep}nav.php";
 require_once "classes{$sep}galleryindex.php";
 require_once "classes{$sep}publisher.php";
 require_once "classes{$sep}themeset.php";
 require_once "classes{$sep}site.php";
 require_once "smarty{$sep}Smarty.class.php";

 
/**
 * Command - Command Show and update images
 * Note that sort and delete are mutually exclusive - delete takes precedence.
 *
 * @package Showkase
 */
 class Sort extends Command {
    function doExecute( Request $request ) {
        $themeSet = new ThemeSet();
        $context = array(
            'token' => $request->newToken(),
            'pageTypes' => $themeSet->getPageTypes()
        );
        $pageSet = new PageSet;
        $pageIndex = $pageSet->getCurrentPageIndex($request);
        $_SESSION['pageIndex'] = $pageIndex;
        $pageRef = $pageSet->getPageRef($pageIndex);
        $pageType = $pageSet->getPageType($pageIndex);
        $pagePath = $pageSet->getPagePath($pageIndex);
        $pageFactory = new PageFactory($themeSet);
        $page = $pageFactory->make($pageType, $pageRef, $pagePath);
        $post = $request->getPost();
        if (isset($post['imagessubmitted'])) {
            try {
                if (!$request->validatePost()) {
                    throw new Exception('No action. Re-submission or remote submission is not allowed.');
                }
                /*
                $page->gallery->setAllImageAttributes($post);
                if ($request->propertyIsSet('index')) {
                    $page->gallery->setIndexThumb($request->getProperty('index'));
                }
                */
                $sortOrder = $request->getProperty('sortOrder');
                $sortOutput = $request->getProperty('sortoutput');
                $page->gallery->setSortOrder($sortOrder);
                $page->gallery->sortImages($sortOutput);
                $page->gallery->saveGallery();
                // next line needed for html galleries
                $page->savePageHtml($pageSet, new Nav($pageFactory, $pageSet), new GalleryIndex($pageSet), new Smarty());
                //$pageSet->setPagesPref('publishing', 'unpublished');
                $pageSet->savePagesPrefs();
                Board::addMessage('New sort order saved');
            } catch (Exception $e) {
                Board::addExceptionMessage($e);
            }
        }
        $imageObjects = $page->gallery->getImageObjects();
        $context['imageCount'] = $page->getImageCount();
        $indexThumb = $page->gallery->getIndexThumb();
        if (empty($indexThumb)) {
            try {
                $page->gallery->updateIndexThumb();
                $page->gallery->saveGallery();
            } catch (Exception $e) {
                Board::addExceptionMessage($e);
            }
        }
        $screen = new SortScreen($page);
        print $screen->getHtml($context);
    }
}
