<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2020, SimpleViewer Inc.
 */
use PHPMailer\PHPMailer\PHPMailer;
error_reporting(E_ERROR);
ini_set('html_errors', 0);
function exception_error_handler($errno, $errstr, $errfile, $errline ) {
    throw new ErrorException($errstr, $errno, 0, $errfile, $errline);
}
set_error_handler("exception_error_handler");
date_default_timezone_set('UTC');
if (!$_POST) return;
require 'PHPMailer.php';
$mailer = new PHPMailer(true);
$mailer->CharSet = 'utf-8';
$mailer->isMail();
$mailer->isHTML(false);
$mailer->WordWrap = 78;
try {
    if (
        !isset($_SERVER['HTTP_X_REQUESTED_WITH'])
        && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) != 'xmlhttprequest'
    ) {
        throw new Exception ('This program is for use by the Showkase contact form only');
    }
    $xmlSourcePath = $_POST['pagePath'].DIRECTORY_SEPARATOR.'page.xml';
    $xmlSource = @file_get_contents($xmlSourcePath);
    if ($xmlSource === false) {
        throw new Exception ('Cannot read page.xml file');
    }
    if ($xmlSource == '') {
        throw new Exception ('No content in page.xml file');
    }
    $domDoc = new DOMDocument();
    $domDoc->preserveWhiteSpace = false;
    $loaded = $domDoc->loadXML($xmlSource);
    if ($loaded === false) {
      $message = '';
      $errors = libxml_get_errors();
      foreach ($errors as $error) {
          $message .= 'XML error in page.xml, line '.$error->line.'. '.$error->message.'<br>';
      }
      libxml_clear_errors();
      throw new Exception($message);
    }
    $settingsTags = $domDoc->getElementsByTagName('settings');
    $tags = $settingsTags->item(0)->childNodes;
    foreach ($tags as $tag) {
      $vars[$tag->nodeName] = $tag->nodeValue;
    }
    // PHPMailer takes care of validation and sanitization
    $subject = isset($vars['ss_contactFormSubject'])
        ? $vars['ss_contactFormSubject']
        : '';
    $siteEmail = isset($vars['ss_contactFormTo'])
        ? $vars['ss_contactFormTo']
        : '';
    $response = isset($vars['ss_contactFormResponse'])
        ? $vars['ss_contactFormResponse']
        : '';
    $userName	   = $_POST["userName"];
    $userEmail	 = $_POST["userEmail"];
    $userMessage = $_POST["userMessage"];
    if(!PHPMailer::validateAddress($siteEmail)) {
    	  throw new Exception ('Site email address is not set or invalid');
    }
    if(strlen($userName) < 1){
    	  throw new Exception ('Please enter your name');
    }
    if(!PHPMailer::validateAddress($userEmail)) {
    	  throw new Exception ('Please enter a valid email');
    }
    if(strlen($userMessage) < 1){
    	  throw new Exception ('Please enter your message text');
    }
    if (stristr($siteEmail, '@') === '@example.com') {
        $output = json_encode(array('type'=>'message', 'text' => $response));
	      die($output);
    }
    $mailer->setFrom('mailer'.strstr($siteEmail, '@'), $userName);
    $mailer->addReplyTo($userEmail, $userName);
    $mailer->addAddress($siteEmail);
    $mailer->Subject = $subject;
    $mailer->Body =
        $userMessage
        ."\r\n\r\n"
        .$userName
        ."\r\n\r\n"
        .$userEmail;
    $mailer->send();
	  $output = json_encode(array('type'=>'message', 'text' => $response));
	  echo($output);
} catch (Exception $e) {
    $output = json_encode(array('type'=>'error', 'text' => $e->getMessage()));
    die($output);
}
