<?php
/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2012, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
require_once 'classes'.DIRECTORY_SEPARATOR.'image.php';
 
/**
 * Autoviewer image
 *
 * @package Showkase
 */
class JuiceboxImage extends Image
{

  /**
   * constructor
   *
   * @param string  gallery path rel svm
   * @param string image path rel gallery or null if not known
   * @param object xml image element
   */
  public function __construct(Page $page, $galleryPathRelSvm, $imagePathRelGallery, $imageData=null)
  {
      parent::__construct($page, $galleryPathRelSvm, $imagePathRelGallery, $imageData);
      if (is_null($imageData)) {
          $this->thumbPathRelGallery = JB_THUMB_PATH.basename($this->imagePathRelGallery);
          $this->thumbUrl = str_replace(array('\\', '/'), '/', $this->thumbPathRelGallery);
      }
      else {
          if ($this->thumbUrl == '') {
            $this->thumbUrl = JB_THUMB_PATH.basename($this->imageUrl);
          }
          $this->thumbPathRelGallery = str_replace(array('\\', '/'), DIRECTORY_SEPARATOR, $this->thumbUrl);
      }
      $this->thumbPathRelGallery = Helpers::changeFileExtension($this->thumbPathRelGallery, 'jpg', array('jpeg', 'JPG', 'JPEG'));
      $this->thumbUrl = Helpers::changeFileExtension($this->thumbUrl, 'jpg', array('jpeg', 'JPG', 'JPEG'));
  }
    
  /**
   * Create dom document to represent the image
   * @return object
   */
  public function getXml()
  {
      $imageUrl = str_replace(array('\\', '/'), '/', $this->imagePathRelGallery);
      $thumbUrl = str_replace(array('\\', '/'), '/', $this->thumbPathRelGallery);
      $parts = pathinfo($imageUrl);
      $multi = $this->page->getMultiImageSettings();
      $domDoc = new domDocument('1.0', 'utf-8');
      $rootElement = $domDoc->createElement('image');
      $domDoc->appendChild($rootElement); 
      $rootElement->setAttribute('imageURL', $imageUrl);
      $rootElement->setAttribute('thumbURL', $thumbUrl);
      $rootElement->setAttribute('linkURL', $this->imageLinkUrl);
      $rootElement->setAttribute('linkTarget', $this->imageLinkTarget);
      if (!empty($this->imagePurchaseUrl)) {
          $rootElement->setAttribute('purchaseURL', $this->imagePurchaseUrl);
      }
      if ($multi['useLargeImages']) {
          $rootElement->setAttribute(
              'largeImageURL',
              $parts['dirname'].'/'
              .JB_LARGE_IMAGE_DIR.'/'
              .$parts['basename']
          );
      }
      if ($multi['useSmallImages']) {
          $rootElement->setAttribute(
              'smallImageURL',
              $parts['dirname'].'/'
              .JB_SMALL_IMAGE_DIR.'/'
              .$parts['basename']);
      }
      $titleElement = $domDoc->createElement('title');
      $titleText = $domDoc->createCDATASection($this->imageTitle);
      $titleElement->appendChild($titleText);
      $rootElement->appendChild($titleElement);
      $captionElement = $domDoc->createElement('caption');
      $captionText = $domDoc->createCDATASection($this->imageCaption);
      $captionElement->appendChild($captionText);
      $rootElement->appendChild($captionElement);
      return $domDoc;
  }
  
  /**
   * Set image attibutes
   *
   * @return void
   * @param string title text
   * @param string caption text
   * @param string link url
   * @param string link target
   * @param integer key to image objects array
   */
  function setImageAttributes($title, $caption, $linkUrl, $linkTarget, $purchase, $i)
  {
      $this->imageCaption = $this->formatImageAttributes($caption, $i);
      $this->imageLinkUrl = $this->formatImageAttributes($linkUrl, $i);
      $this->imageTitle = $this->formatImageAttributes($title, $i);
      $this->imageLinkTarget = $linkTarget;
      $this->imagePurchaseUrl = $this->formatImageAttributes($purchase, $i);
  }
}
