<?php
 /**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2012, SimpleViewer Inc.
 */
defined('SK_ACCESS')||die('<h1>403: Forbidden</h1>');
require_once 'classes'.DIRECTORY_SEPARATOR.'screen.php';
require_once 'classes'.DIRECTORY_SEPARATOR.'helpers.php';

 
 /**
  * Images screen
  *
  * @package Showkase
  */
  class LibraryBrowseImagesScreen extends Screen
  {
   /**
    * @var string overrides some of html in parent
    */
    var $customHeadHtml = '
    <script src="scripts/jlibrarybrowse.js" type="text/javascript"></script>
    ';
    
   /**
    * constructs ImagesScreen class
    * @param string contains text for html <title></title> tags
    * @param string html id for body tag
    */
    function __construct($page)
    {
      parent::__construct('Showkase &ndash; browse library', 'browse-library', 'pages images library');
      $this->pageType = 'library';
      $this->page = $page;
      $bb = new LibraryBrowseButtonbar();
    }
      
  /**
    * Returns special header for this page
    * Overrides method in Screen
    *
    @return string
    @access public
    */
    public function getScreenHeader(array $context, $messages)
    {     
      $header = <<<EOD
  <body id="{$this->bodyId}" class="{$this->bodyClass}">
  	<div id="wrapper">
      <div id="header">
      <br class="clearboth" />
      </div>
      <div id="content">
EOD;
      return $header;
    }

   /**
    * get html for images screen
    * Note that some class names are significant for manager.js
    *
    * @access public
    * @return string html
    * @param string gallery reference number
    * @param array image data
    */
    function getContentHtml($context)
    {
      if ($context['imageCount'] == 0) return '
  <div class="subhead">
    <div class="hgroup">
      <h2>Insert library image</h2>
    </div>
    <ul class="buttons">
      <li class="btn btn-danger"><a class="closewindow" href="index.php">Cancel</a></li>
    </ul>
  </div>
  <p class="info">Your image library is empty. Cancel and go to Library &gt; Upload to add images.</p>';
      $callback = is_null($context['callback']) ? '"none"' : $context['callback'];
      $gallery = $this->page->gallery;
      $imageObjects = $gallery->getImageObjects();
      $galleryRef = $gallery->getGalleryRef();
      $host = Helpers::getHost();
      $html = <<<EOD
  <script type='text/javascript'>
    var callback = {$callback};
  </script>
  <div class="subhead">
    <div class="hgroup">
      <h2>Insert library image</h2>
    </div>
    <ul class="buttons">
      <li class="btn btn-danger"><a class="closewindow" href="index.php">Cancel</a></li>
    </ul>
  </div>
  <p class="info">Click a thumbnail to insert the image in your page</p>
  <table cellspacing="0" class="imagelist" id="imagelisttable">
    <thead>
      <tr><th class="ilfilename">Insert</th><th>File name</th><th class="ilcaption">http://{$host}</th></tr>
    </thead>
    <tbody>
EOD;
      $i = 0;
      foreach ($imageObjects as $key => $imageObject)
      {
        $relativeUrl = $gallery->getUrlRelSvm($imageObject->getImagePathRelGallery());
        $absUrl = str_replace('\\', '/', $imageObject->getImagePathRelGallery());
        $fileName = $imageObject->getImageFileName();
        $thumbName = Helpers::changeFileExtension($fileName, 'jpg', array('jpeg', 'JPG', 'JPEG'));
        $src = file_exists($gallery->getThumbDirPathRelSvm().$thumbName) ?
          htmlspecialchars($gallery->getThumbDirUrlRelSvm().$thumbName, ENT_QUOTES, 'UTF-8') :
          rtrim(IMAGE_SRC, '\\/').'/nothumb.gif';
        $fileName = htmlspecialchars($fileName, ENT_QUOTES, 'UTF-8');
        $imageSize = $imageObject->getImageSizeArray();
        if ($imageSize === false) $sizeString = '';
        else $sizeString = '<br />('.$imageSize[0].' x '.$imageSize[1].')';
        $chkBoxId = 'cap'.$i;
        $html .= '
        <tr>
          <td class="ilthumbnail"><a href="'.htmlspecialchars($gallery->getRootUrl().$absUrl, ENT_QUOTES, 'UTF-8').'" target="preview"><img src="'.$src.'" width="'.THUMB_DISPLAY_SIZE.'" height="'.THUMB_DISPLAY_SIZE.'" alt="" /></a></td>
          <td class="ilfilename"><div class="truncate">'.$fileName.$sizeString.'</div></td>
          <td class="ilcaption">'.htmlspecialchars($gallery->getRootUrl().$absUrl, ENT_QUOTES, 'UTF-8').'</td>
        </tr>';
        $i++;
      }
      $html .= '
        </tbody>
      </table>
';
      return $html;
    }

}

