/**
 * Part of Showkase web site management package
 *
 * @package Showkase
 * @author Jack Hardie {@link http://www.jhardie.com}
 * @copyright Copyright (c) 2015, SimpleViewer Inc.
 */
 
if (!String.prototype.trim) {
  String.prototype.trim = function () {
    return this.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, '');
  };
}

var skGlobals = {
  lastClicked: ''
};

function changeCheck() {
  // handle no pages and cancel
  if (
    !$('#container').length || skGlobals.lastClicked === 'cancel'
    ) {
    return false;
  }
  var treejson = $('#container').jstree(true).get_json("#", {flat:false, no_state:true}),
  serialTree = JSON.stringify(treejson);
  if (serialTree !== $("#treejson").val()) {
    return true;
  }
}

/**
 * Modify jsTree standard menu
 */
function customMenu(node) {
  var tmp = $.jstree.defaults.contextmenu.items.call(this, node),
      skItems = {},
      nodePath = this.get_path(node, false, true),
      topLevelId = nodePath[0];
  if (this.get_parent(node) !== "#") {
    /*
    skItems.view = {
      "label" : "View",
      "separator_after" : true,
      "action" : function (data) {
        var inst = $.jstree.reference(data.reference),
  		  obj = inst.get_node(data.reference);
  		  window.open(obj.data.pageurl, 'preview');
      }
    };
    */
    skItems.show = {
      "label" : "Show",
      "separator_after" : true,
      "action" : function (data) {
  				var inst = $.jstree.reference(data.reference),
  				obj = inst.get_node(data.reference);
          inst.move_node(obj, "ref0");
      }
    };
    skItems.hide = {
      "label" : "Hide",
      "separator_after" : true,
      "action" : function (data) {
  				var inst = $.jstree.reference(data.reference),
  				obj = inst.get_node(data.reference);
          inst.move_node(obj, "ref-1");
      }
    };
    skItems.trash = {
      "label" : "Trash",
      "separator_after" : true,
      "action" : function (data) {
  				var inst = $.jstree.reference(data.reference),
  				obj = inst.get_node(data.reference);
          inst.move_node(obj, "ref-2");
      }
    };
    skItems.cut = tmp.ccp.submenu.cut;
  }
  if (
    typeof skItems.show !== "undefined" && topLevelId === "ref0"
  ) {
    skItems.show._disabled = true;
  }
  if (
    typeof skItems.hide !== "undefined" && topLevelId === "ref-1"
  ) {
    skItems.hide._disabled = true;
  }
  if (
    typeof skItems.trash !== "undefined" && topLevelId === "ref-2"
  ) {
    skItems.trash._disabled = true;
  }
  skItems.paste = tmp.ccp.submenu.paste;
  return skItems;
}

/**
 * Add classes to indicate cut and paste
 */
$(function(){
  $('#container').on('cut.jstree', function (e, data) {
    $.each(data.node, function(index, nodeId) {
      $('#' + nodeId).addClass('cut');
    });
  });
  $('#container').on('paste.jstree', function (e, data){
    $.each(data.node, function(index, cutNode) {
      $('#' + cutNode.id).removeClass('cut');
    });
  });
});

/**
 * Save initial state
 * Hidden and trash nodes have default open and are closed here.
 * Otherwise opening these nodes and clicking pencil icon triggers onbeforeunload dialog
 * even if nothing has changed
 */
$(function() {
  $("#container").on('ready.jstree', function(e, data) {
    var jst = $(this).jstree(true),
        treejson = $(this).jstree(true).get_json("#", {flat:false, no_state:true}),
        hidden = $('#container').jstree(true).get_node('ref-1'),
        trash = $('#container').jstree(true).get_node('ref-2');
    jst.close_node(hidden, false);
    jst.close_node(trash, false);
    
    // copy initial state to form field
    $("#treejson").val(JSON.stringify(treejson));
  });
});

/**
 * Check before leaving page
 */
$(function() {
  window.onbeforeunload = function(e) {
    if(changeCheck()) {
      return 'You have unsaved changes. Do you want to leave this page?';
    }
  };
});

/**
 * Check before publishing
 */
$(function() {
  $('.republish').click(function(e) {
    if(changeCheck()) {
      return window.confirm('You have unsaved changes, do you still want to publish?');
    }
  });
});

/**
 * Check before delete
 */
$(function() {
  $("#pagesform").on("submit", function (e, data) {
      // handle no pages case
      if (!$('#container').length) {
        return;
      }
      var treejson = $("#container").jstree(true).get_json("#", {flat:false, no_state:true}),
          deletions = 0;
      // copy to form field
      $("#treejson").val(JSON.stringify(treejson));
      // count deletions
      $.each(treejson, function(key, treeNode){
          if (treeNode.type === 'trash') {
            if (treeNode.children.length > 0) {
              $.each(treeNode.children, function(key, pageNode) {
                deletions += 1;
                deletions += pageNode.children.length;
              });
            }
          }
      });
      if (deletions < 1) {
        return true;
      }
      if (deletions === 1) {
        return window.confirm("Deleting 1 page from the trash folder");
      }
      return window.confirm("Deleting " + deletions + " pages from the trash folder");
    });
});


/**
 * Close any open rename fields
 * dnd_start is triggered on the document in the 'vakata' namespace
 */
$(function() {
  $(document).on('dnd_start.vakata', function(e, data) {
    $('input').blur();
  });
});

/**
 * Easy way for user to deselect all nodes
 * https://css-tricks.com/dangers-stopping-event-propagation/
 */
$(function() { 
  $("#wrapper").on("click", function(e) {
    // handle no pages case
    if (!$('#container').length) {
      return;
    }
    if (!$(e.target).closest('#container').length) {
      $("#container").jstree(true).deselect_all(true);
    }
  });
});


/**
 * Actions
 */
$(function() {
  $("#container").on("click", ".sk-action", function (e) {
    var jTarget = $(e.target),
        inst = $(this).jstree(true),
        obj = inst.get_node(e.target);
    if ($(document.activeElement).hasClass('jstree-rename-input')) {
      // close rename input
      return true;
    }
    if (jTarget.hasClass("sk-edit")) {
      window.location.href = "index.php?cmd=pagecustomize&pageIndex=" + obj.data.pageindex;
    }
    if (jTarget.hasClass("sk-view")) {
      if (jTarget.hasClass("unsupported")) {
        return false;
      }
      if(
        !changeCheck() || window.confirm('Unsaved changes will not show in view, do you want to continue?')
      ) {
        window.open(obj.data.pageurl, 'preview');
      }
      
    }
    if (jTarget.hasClass("sk-trash")) {
        inst.move_node(obj, "ref-2");
    }
    if (jTarget.hasClass("sk-rename")) {
      // store old values in a closure before edit
      var
        oldText = obj.text,
		    oldNavName = obj.data.navname,
		    defaultText = oldNavName
		      .replace(/&amp;/g, '&')
		      .replace(/&lt;/g, '<')
		      .replace(/&gt;/, '>');
		    // force text during rename to leave &lt; characters unchanged
		    inst.settings.core.force_text = true; 
			inst.edit(obj, defaultText, function(node, status, cancelled) {
  			if (cancelled) {
      		node.text = oldText;
      		this.settings.core.force_text = false;
      		this.redraw(true);
      		return true;
      	}
        var newNavName = node.text
          .replace(/</g, '&lt;')
          .trim();
      	if (newNavName.length === 0) {
        	// safety feature probably not needed
        	window.alert('Not renamed. Name cannot be empty.');
      		newNavName = oldNavName;
      	}
      	// store plain text navname in node.data
      	node.data.navname = newNavName;
      	// store navname wrapped in span tags in node.text
      	node.text = oldText.replace(oldNavName, newNavName);
      	// restore html text after rename
      	this.settings.core.force_text = false;
      	this.redraw(true);
      	return true;
			});
    }
  });
});

