/**
 * Convert div to queue widget
 * Code adapted from http://www.plupload.com/example_queuewidget.php
 */
$(function() {
    var initSettings = {
        // General settings. Empty object for resize seems necessary.
        runtimes : 'html5,html4',
        url : '',
        chunk_size : '1mb',
        unique_names : false,
        multiple_queues : true,
        resize : {},
        filters : [
            {title : "Image files", extensions : "jpg,jpeg,gif,png"}
        ],    
        // PreInit events, bound before any internal events
        preinit : {
            Init: function(up, info) {
                var runtimeName;
                switch(info.runtime) {
                  case('html5') :
                     runtimeName = 'HTML5';
                     break;
                  case('html4') :
                     runtimeName = 'Basic';
                     break;
                  default :
                     runtimeName = info.runtime;
                }
                $('ul.features').append(
                    '<li>Using ' + runtimeName + ' upload option</li>'
                );
                var html5Link = '<a href="index.php?cmd=' + cmd + '&runtime=html5' + sid +'">';
                var html4Link = '<a href="index.php?cmd=' + cmd + '&runtime=html4' + sid + '">';
                var swapRuntime = 'Change to ' + html4Link + 'Basic upload</a>';
                if (info.runtime == 'html4') {
                    swapRuntime = 'Change to ' + html5Link + 'HTML5 upload</a>' ;
                }
                $('#swaps').append(swapRuntime);
                $('ul.features').append(
                    up.features.chunks
                    ? '<li>No file size limit</li>'
                    : '<li>Max file size ' + maxMBytes + 'MB</li>'
                ); 
                $('ul.features').append(
                    up.features.dragdrop
                    ? '<li>Drag and drop supported</li>'
                    : '<li class="unsupported">Drag and drop not supported</li>'
                );
                $('ul.features').append(
                    up.features.multi_selection
                    ? '<li>Multi-file selection supported</li>'
                    : '<li class="unsupported">Multi-file selection not supported</li>'
                );
                /* up.features.jpgresize does not appear to be supported in Plupload 2 */
                if (info.runtime == 'html4') {
                    $('ul.features').append('<li class="unsupported">Image resize not supported</li>');
                    $('#resizeOn').prop({disabled : true, checked : false});
                }
            },
            UploadFile: function(up, file) {
        				// Override settings before the file is uploaded
        				// User may have changed resize settings between uploads
        				var maxImageWidth  = parseInt($('#maxImageWidth').val(), 10);
        				var maxImageHeight = parseInt($('#maxImageHeight').val(), 10);
        				var compressionQuality =
        				    Math.max(
        				        1, Math.min(100,
        				            parseInt(
        				                $('#compressionQuality').val(), 10
        				            )
        				        )
        				    );
                if (
                    $('#resizeOn').prop('checked')
                    && maxImageWidth >= 0
                    && maxImageHeight >= 0
                ) {
                    up.settings.resize.width = maxImageWidth;
                    up.settings.resize.height = maxImageHeight;
                    up.settings.resize.quality = compressionQuality;
                } else {
                    // Deleting all up.settings.resize.property did not turn off resize
                    up.settings.resize = {};
                }
        		}
        },
    
        // Post init events, bound after the internal events
        init : {
            FileUploaded: function(up, file, info) {
                // Called when a file has finished uploading
                //log('[FileUploaded] File:', file, "Info:", info);
                response = jQuery.parseJSON(info.response);
                if (response.error && response.error.code){
                    file.status = plupload.FAILED;
                    up.trigger('QueueChanged');
                    up.trigger('Error', {
                        code : response.error.code,
                        message : response.error.message,
                        details : response.details,
                        file : file
                    });
                }
            },
            UploadComplete: function(up, files) {
                // Called when all files are either uploaded or failed
            }
        }
    };
    // Overwrite defaults with settings written into page script by php
    $.extend(initSettings, phpSettings);
    // Initiate queue widget
    $("#uploader").pluploadQueue(initSettings);
});
